=================================
Flask-IO
=================================
Flask-IO is a library for parsing Flask request arguments into parameters and for serialization of complex objects into Flask response.

Installation
===============
You can install Flask-IO via Python Package Index (PyPi_),::

    $ pip install flask-io

Documentation
===============
Full documentation is available at https://flask-io.readthedocs.org/.

Feedback
===============
Please use the Issues_ for feature requests and troubleshooting usage.

.. |Version| image:: https://badge.fury.io/py/flask-io.svg?
   :target: http://badge.fury.io/py/flask-io

.. _example: https://github.com/viniciuschiele/flask-io/tree/master/example

.. _PyPi: https://pypi.python.org/pypi/flask-io

.. _Issues: https://github.com/viniciuschiele/flask-io/issues
